@@ -328,6 +328,10 @@ class OpenAIBaseStreamingClient(PlaygroundStreamingClient):
                 label="Response Format",
                 canonical_name=CanonicalParameterName.RESPONSE_FORMAT,
             ),
+            JSONInvocationParameter(
+                invocation_name="extra_body",
+                label="Extra Body",
+            ),
         ]
 
     async def chat_completion_create(
@@ -699,7 +703,7 @@ class BedrockStreamingClient(PlaygroundStreamingClient):
         self.model_name = model.name
         self.client = boto3.client(
             service_name="bedrock-runtime",
-            region_name="us-east-1",  # match the default region in the UI
+            region_name=self.region,
             aws_access_key_id=self.aws_access_key_id,
             aws_secret_access_key=self.aws_secret_access_key,
             aws_session_token=self.aws_session_token,
@@ -805,7 +809,7 @@ class BedrockStreamingClient(PlaygroundStreamingClient):
 
         # Build the request parameters for Converse API
         converse_params: dict[str, Any] = {
-            "modelId": f"us.{self.model_name}",
+            "modelId": self.model_name,
             "messages": converse_messages,
             "inferenceConfig": {
                 "maxTokens": invocation_parameters["max_tokens"],
@@ -953,7 +957,7 @@ class BedrockStreamingClient(PlaygroundStreamingClient):
         }
 
         response = self.client.invoke_model_with_response_stream(
-            modelId=f"us.{self.model_name}",  # or another Claude model
+            modelId=self.model_name,
             contentType="application/json",
             accept="application/json",
             body=json.dumps(bedrock_params),
@@ -1231,6 +1235,10 @@ class OpenAIReasoningReasoningModelsMixin:
                 label="Response Format",
                 canonical_name=CanonicalParameterName.RESPONSE_FORMAT,
             ),
+            JSONInvocationParameter(
+                invocation_name="extra_body",
+                label="Extra Body",
+            ),
         ]
 
 
@@ -1462,13 +1470,8 @@ class AzureOpenAIReasoningNonStreamingClient(
     provider_key=GenerativeProviderKey.ANTHROPIC,
     model_names=[
         PROVIDER_DEFAULT,
-        "claude-3-5-sonnet-latest",
         "claude-3-5-haiku-latest",
-        "claude-3-5-sonnet-20241022",
         "claude-3-5-haiku-20241022",
-        "claude-3-5-sonnet-20240620",
-        "claude-3-opus-latest",
-        "claude-3-sonnet-20240229",
         "claude-3-haiku-20240307",
     ],
 )
@@ -1678,10 +1681,13 @@ class AnthropicStreamingClient(PlaygroundStreamingClient):
     provider_key=GenerativeProviderKey.ANTHROPIC,
     model_names=[
         "claude-sonnet-4-5",
-        "claude-sonnet-4-0",
-        "claude-sonnet-4-20250514",
+        "claude-sonnet-4-5-20250929",
+        "claude-haiku-4-5",
+        "claude-haiku-4-5-20251001",
         "claude-opus-4-1",
         "claude-opus-4-1-20250805",
+        "claude-sonnet-4-0",
+        "claude-sonnet-4-20250514",
         "claude-opus-4-0",
         "claude-opus-4-20250514",
         "claude-3-7-sonnet-latest",
