@@ -1,37 +1,18 @@
-from __future__ import annotations
-
 from enum import Enum
 from typing import Any, Literal, Mapping, Optional, Union
 
-from pydantic import BaseModel, ConfigDict, Field, RootModel, model_validator
+from pydantic import Field, RootModel, model_validator
 from typing_extensions import Annotated, Self, TypeAlias, TypeGuard, assert_never
 
+from phoenix.db.types.db_models import UNDEFINED, DBBaseModel
 from phoenix.db.types.model_provider import ModelProvider
 from phoenix.server.api.helpers.prompts.conversions.anthropic import AnthropicToolChoiceConversion
+from phoenix.server.api.helpers.prompts.conversions.aws import AwsToolChoiceConversion
 from phoenix.server.api.helpers.prompts.conversions.openai import OpenAIToolChoiceConversion
 
 JSONSerializable = Union[None, bool, int, float, str, dict[str, Any], list[Any]]
 
 
-class Undefined:
-    """
-    A singleton class that represents an unset or undefined value. Needed since Pydantic
-    can't natively distinguish between an undefined value and a value that is set to
-    None.
-    """
-
-    def __new__(cls) -> Any:
-        if not hasattr(cls, "_instance"):
-            cls._instance = super().__new__(cls)
-        return cls._instance
-
-    def __bool__(self) -> bool:
-        return False
-
-
-UNDEFINED: Any = Undefined()
-
-
 class PromptTemplateType(str, Enum):
     STRING = "STR"
     CHAT = "CHAT"
@@ -50,33 +31,18 @@ class PromptTemplateFormat(str, Enum):
     NONE = "NONE"
 
 
-class PromptModel(BaseModel):
-    model_config = ConfigDict(
-        extra="forbid",  # disallow extra attributes
-        use_enum_values=True,
-        validate_assignment=True,
-    )
-
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        kwargs = {k: v for k, v in kwargs.items() if v is not UNDEFINED}
-        super().__init__(*args, **kwargs)
-
-    def model_dump(self, *args: Any, **kwargs: Any) -> dict[str, Any]:
-        return super().model_dump(*args, exclude_unset=True, by_alias=True, **kwargs)
-
-
-class TextContentPart(PromptModel):
+class TextContentPart(DBBaseModel):
     type: Literal["text"]
     text: str
 
 
-class ToolCallFunction(PromptModel):
+class ToolCallFunction(DBBaseModel):
     type: Literal["function"]
     name: str
     arguments: str
 
 
-class ToolCallContentPart(PromptModel):
+class ToolCallContentPart(DBBaseModel):
     type: Literal["tool_call"]
     tool_call_id: str
     tool_call: Annotated[
@@ -85,7 +51,7 @@ class ToolCallContentPart(PromptModel):
     ]
 
 
-class ToolResultContentPart(PromptModel):
+class ToolResultContentPart(DBBaseModel):
     type: Literal["tool_result"]
     tool_call_id: str
     tool_result: JSONSerializable
@@ -131,17 +97,17 @@ class RoleConversion:
         assert_never(role)
 
 
-class PromptMessage(PromptModel):
+class PromptMessage(DBBaseModel):
     role: Role
     content: Union[str, Annotated[list[ContentPart], Field(..., min_length=1)]]
 
 
-class PromptChatTemplate(PromptModel):
+class PromptChatTemplate(DBBaseModel):
     type: Literal["chat"]
     messages: list[PromptMessage]
 
 
-class PromptStringTemplate(PromptModel):
+class PromptStringTemplate(DBBaseModel):
     type: Literal["string"]
     template: str
 
@@ -159,41 +125,34 @@ class PromptTemplateRootModel(RootModel[PromptTemplate]):
     root: PromptTemplate
 
 
-class PromptToolFunction(PromptModel):
-    type: Literal["function"]
-    function: PromptToolFunctionDefinition
-
-
-class PromptToolFunctionDefinition(PromptModel):
+class PromptToolFunctionDefinition(DBBaseModel):
     name: str
     description: str = UNDEFINED
     parameters: dict[str, Any] = UNDEFINED
     strict: bool = UNDEFINED
 
 
+class PromptToolFunction(DBBaseModel):
+    type: Literal["function"]
+    function: PromptToolFunctionDefinition
+
+
 PromptTool: TypeAlias = Annotated[Union[PromptToolFunction], Field(..., discriminator="type")]
 
 
-class PromptTools(PromptModel):
-    type: Literal["tools"]
-    tools: Annotated[list[PromptTool], Field(..., min_length=1)]
-    tool_choice: PromptToolChoice = UNDEFINED
-    disable_parallel_tool_calls: bool = UNDEFINED
-
-
-class PromptToolChoiceNone(PromptModel):
+class PromptToolChoiceNone(DBBaseModel):
     type: Literal["none"]
 
 
-class PromptToolChoiceZeroOrMore(PromptModel):
+class PromptToolChoiceZeroOrMore(DBBaseModel):
     type: Literal["zero_or_more"]
 
 
-class PromptToolChoiceOneOrMore(PromptModel):
+class PromptToolChoiceOneOrMore(DBBaseModel):
     type: Literal["one_or_more"]
 
 
-class PromptToolChoiceSpecificFunctionTool(PromptModel):
+class PromptToolChoiceSpecificFunctionTool(DBBaseModel):
     type: Literal["specific_function"]
     function_name: str
 
@@ -209,7 +168,14 @@ PromptToolChoice: TypeAlias = Annotated[
 ]
 
 
-class PromptOpenAIJSONSchema(PromptModel):
+class PromptTools(DBBaseModel):
+    type: Literal["tools"]
+    tools: Annotated[list[PromptTool], Field(..., min_length=1)]
+    tool_choice: PromptToolChoice = UNDEFINED
+    disable_parallel_tool_calls: bool = UNDEFINED
+
+
+class PromptOpenAIJSONSchema(DBBaseModel):
     """
     Based on https://github.com/openai/openai-python/blob/d16e6edde5a155626910b5758a0b939bfedb9ced/src/openai/types/shared/response_format_json_schema.py#L13
     """
@@ -223,7 +189,7 @@ class PromptOpenAIJSONSchema(PromptModel):
     strict: Optional[bool] = UNDEFINED
 
 
-class PromptOpenAIResponseFormatJSONSchema(PromptModel):
+class PromptOpenAIResponseFormatJSONSchema(DBBaseModel):
     """
     Based on https://github.com/openai/openai-python/blob/d16e6edde5a155626910b5758a0b939bfedb9ced/src/openai/types/shared/response_format_json_schema.py#L40
     """
@@ -232,18 +198,18 @@ class PromptOpenAIResponseFormatJSONSchema(PromptModel):
     type: Literal["json_schema"]
 
 
-class PromptResponseFormatJSONSchema(PromptModel):
-    type: Literal["json_schema"]
-    json_schema: PromptResponseFormatJSONSchemaDefinition
-
-
-class PromptResponseFormatJSONSchemaDefinition(PromptModel):
+class PromptResponseFormatJSONSchemaDefinition(DBBaseModel):
     name: str
     description: str = UNDEFINED
     schema_: dict[str, Any] = Field(UNDEFINED, alias="schema")
     strict: bool = UNDEFINED
 
 
+class PromptResponseFormatJSONSchema(DBBaseModel):
+    type: Literal["json_schema"]
+    json_schema: PromptResponseFormatJSONSchemaDefinition
+
+
 PromptResponseFormat: TypeAlias = Annotated[
     Union[PromptResponseFormatJSONSchema], Field(..., discriminator="type")
 ]
@@ -305,7 +271,7 @@ def denormalize_response_format(
 
 
 # OpenAI tool definitions
-class OpenAIFunctionDefinition(PromptModel):
+class OpenAIFunctionDefinition(DBBaseModel):
     """
     Based on https://github.com/openai/openai-python/blob/1e07c9d839e7e96f02d0a4b745f379a43086334c/src/openai/types/shared_params/function_definition.py#L13
     """
@@ -316,7 +282,7 @@ class OpenAIFunctionDefinition(PromptModel):
     strict: Optional[bool] = UNDEFINED
 
 
-class OpenAIToolDefinition(PromptModel):
+class OpenAIToolDefinition(DBBaseModel):
     """
     Based on https://github.com/openai/openai-python/blob/1e07c9d839e7e96f02d0a4b745f379a43086334c/src/openai/types/chat/chat_completion_tool_param.py#L12
     """
@@ -326,7 +292,7 @@ class OpenAIToolDefinition(PromptModel):
 
 
 # Anthropic tool definitions
-class AnthropicCacheControlParam(PromptModel):
+class AnthropicCacheControlParam(DBBaseModel):
     """
     Based on https://github.com/anthropics/anthropic-sdk-python/blob/93cbbbde964e244f02bf1bd2b579c5fabce4e267/src/anthropic/types/cache_control_ephemeral_param.py#L10
     """
@@ -334,7 +300,7 @@ class AnthropicCacheControlParam(PromptModel):
     type: Literal["ephemeral"]
 
 
-class AnthropicToolDefinition(PromptModel):
+class AnthropicToolDefinition(DBBaseModel):
     """
     Based on https://github.com/anthropics/anthropic-sdk-python/blob/93cbbbde964e244f02bf1bd2b579c5fabce4e267/src/anthropic/types/tool_param.py#L22
     """
@@ -345,7 +311,15 @@ class AnthropicToolDefinition(PromptModel):
     description: str = UNDEFINED
 
 
-class PromptOpenAIInvocationParametersContent(PromptModel):
+class BedrockToolDefinition(DBBaseModel):
+    """
+    Based on https://github.com/aws/amazon-bedrock-sdk-python/blob/main/src/bedrock/types/tool_param.py#L12
+    """
+
+    toolSpec: dict[str, Any]
+
+
+class PromptOpenAIInvocationParametersContent(DBBaseModel):
     temperature: float = UNDEFINED
     max_tokens: int = UNDEFINED
     max_completion_tokens: int = UNDEFINED
@@ -353,10 +327,10 @@ class PromptOpenAIInvocationParametersContent(PromptModel):
     presence_penalty: float = UNDEFINED
     top_p: float = UNDEFINED
     seed: int = UNDEFINED
-    reasoning_effort: Literal["low", "medium", "high"] = UNDEFINED
+    reasoning_effort: Literal["minimal", "low", "medium", "high"] = UNDEFINED
 
 
-class PromptOpenAIInvocationParameters(PromptModel):
+class PromptOpenAIInvocationParameters(DBBaseModel):
     type: Literal["openai"]
     openai: PromptOpenAIInvocationParametersContent
 
@@ -365,21 +339,48 @@ class PromptAzureOpenAIInvocationParametersContent(PromptOpenAIInvocationParamet
     pass
 
 
-class PromptAzureOpenAIInvocationParameters(PromptModel):
+class PromptDeepSeekInvocationParametersContent(PromptOpenAIInvocationParametersContent):
+    pass
+
+
+class PromptXAIInvocationParametersContent(PromptOpenAIInvocationParametersContent):
+    pass
+
+
+class PromptOllamaInvocationParametersContent(PromptOpenAIInvocationParametersContent):
+    pass
+
+
+class PromptAzureOpenAIInvocationParameters(DBBaseModel):
     type: Literal["azure_openai"]
     azure_openai: PromptAzureOpenAIInvocationParametersContent
 
 
-class PromptAnthropicThinkingConfigDisabled(PromptModel):
+class PromptDeepSeekInvocationParameters(DBBaseModel):
+    type: Literal["deepseek"]
+    deepseek: PromptDeepSeekInvocationParametersContent
+
+
+class PromptXAIInvocationParameters(DBBaseModel):
+    type: Literal["xai"]
+    xai: PromptXAIInvocationParametersContent
+
+
+class PromptOllamaInvocationParameters(DBBaseModel):
+    type: Literal["ollama"]
+    ollama: PromptOllamaInvocationParametersContent
+
+
+class PromptAnthropicThinkingConfigDisabled(DBBaseModel):
     type: Literal["disabled"]
 
 
-class PromptAnthropicThinkingConfigEnabled(PromptModel):
+class PromptAnthropicThinkingConfigEnabled(DBBaseModel):
     type: Literal["enabled"]
     budget_tokens: int = Field(..., ge=1024)
 
 
-class PromptAnthropicInvocationParametersContent(PromptModel):
+class PromptAnthropicInvocationParametersContent(DBBaseModel):
     max_tokens: int
     temperature: float = UNDEFINED
     top_p: float = UNDEFINED
@@ -398,12 +399,23 @@ class PromptAnthropicInvocationParametersContent(PromptModel):
         return self
 
 
-class PromptAnthropicInvocationParameters(PromptModel):
+class PromptAnthropicInvocationParameters(DBBaseModel):
     type: Literal["anthropic"]
     anthropic: PromptAnthropicInvocationParametersContent
 
 
-class PromptGoogleInvocationParametersContent(PromptModel):
+class PromptAwsInvocationParametersContent(DBBaseModel):
+    max_tokens: int = UNDEFINED
+    temperature: float = UNDEFINED
+    top_p: float = UNDEFINED
+
+
+class PromptAwsInvocationParameters(DBBaseModel):
+    type: Literal["aws"]
+    aws: PromptAwsInvocationParametersContent
+
+
+class PromptGoogleInvocationParametersContent(DBBaseModel):
     temperature: float = UNDEFINED
     max_output_tokens: int = UNDEFINED
     stop_sequences: list[str] = UNDEFINED
@@ -413,7 +425,7 @@ class PromptGoogleInvocationParametersContent(PromptModel):
     top_k: int = UNDEFINED
 
 
-class PromptGoogleInvocationParameters(PromptModel):
+class PromptGoogleInvocationParameters(DBBaseModel):
     type: Literal["google"]
     google: PromptGoogleInvocationParametersContent
 
@@ -424,6 +436,10 @@ PromptInvocationParameters: TypeAlias = Annotated[
         PromptAzureOpenAIInvocationParameters,
         PromptAnthropicInvocationParameters,
         PromptGoogleInvocationParameters,
+        PromptDeepSeekInvocationParameters,
+        PromptXAIInvocationParameters,
+        PromptOllamaInvocationParameters,
+        PromptAwsInvocationParameters,
     ],
     Field(..., discriminator="type"),
 ]
@@ -440,6 +456,14 @@ def get_raw_invocation_parameters(
         return invocation_parameters.anthropic.model_dump()
     if isinstance(invocation_parameters, PromptGoogleInvocationParameters):
         return invocation_parameters.google.model_dump()
+    if isinstance(invocation_parameters, PromptDeepSeekInvocationParameters):
+        return invocation_parameters.deepseek.model_dump()
+    if isinstance(invocation_parameters, PromptXAIInvocationParameters):
+        return invocation_parameters.xai.model_dump()
+    if isinstance(invocation_parameters, PromptOllamaInvocationParameters):
+        return invocation_parameters.ollama.model_dump()
+    if isinstance(invocation_parameters, PromptAwsInvocationParameters):
+        return invocation_parameters.aws.model_dump()
     assert_never(invocation_parameters)
 
 
@@ -453,6 +477,10 @@ def is_prompt_invocation_parameters(
             PromptAzureOpenAIInvocationParameters,
             PromptAnthropicInvocationParameters,
             PromptGoogleInvocationParameters,
+            PromptDeepSeekInvocationParameters,
+            PromptXAIInvocationParameters,
+            PromptOllamaInvocationParameters,
+            PromptAwsInvocationParameters,
         ),
     )
 
@@ -477,6 +505,13 @@ def validate_invocation_parameters(
                 invocation_parameters
             ),
         )
+    elif model_provider is ModelProvider.DEEPSEEK:
+        return PromptDeepSeekInvocationParameters(
+            type="deepseek",
+            deepseek=PromptDeepSeekInvocationParametersContent.model_validate(
+                invocation_parameters
+            ),
+        )
     elif model_provider is ModelProvider.ANTHROPIC:
         return PromptAnthropicInvocationParameters(
             type="anthropic",
@@ -489,6 +524,21 @@ def validate_invocation_parameters(
             type="google",
             google=PromptGoogleInvocationParametersContent.model_validate(invocation_parameters),
         )
+    elif model_provider is ModelProvider.XAI:
+        return PromptXAIInvocationParameters(
+            type="xai",
+            xai=PromptXAIInvocationParametersContent.model_validate(invocation_parameters),
+        )
+    elif model_provider is ModelProvider.OLLAMA:
+        return PromptOllamaInvocationParameters(
+            type="ollama",
+            ollama=PromptOllamaInvocationParametersContent.model_validate(invocation_parameters),
+        )
+    elif model_provider is ModelProvider.AWS:
+        return PromptAwsInvocationParameters(
+            type="aws",
+            aws=PromptAwsInvocationParametersContent.model_validate(invocation_parameters),
+        )
     assert_never(model_provider)
 
 
@@ -498,18 +548,36 @@ def normalize_tools(
     tool_choice: Optional[Union[str, Mapping[str, Any]]] = None,
 ) -> PromptTools:
     tools: list[PromptToolFunction]
-    if model_provider is ModelProvider.OPENAI or model_provider is ModelProvider.AZURE_OPENAI:
+    if (
+        model_provider is ModelProvider.OPENAI
+        or model_provider is ModelProvider.AZURE_OPENAI
+        or model_provider is ModelProvider.DEEPSEEK
+        or model_provider is ModelProvider.XAI
+        or model_provider is ModelProvider.OLLAMA
+    ):
         openai_tools = [OpenAIToolDefinition.model_validate(schema) for schema in schemas]
         tools = [_openai_to_prompt_tool(openai_tool) for openai_tool in openai_tools]
+    elif model_provider is ModelProvider.AWS:
+        bedrock_tools = [BedrockToolDefinition.model_validate(schema) for schema in schemas]
+        tools = [_bedrock_to_prompt_tool(bedrock_tool) for bedrock_tool in bedrock_tools]
     elif model_provider is ModelProvider.ANTHROPIC:
         anthropic_tools = [AnthropicToolDefinition.model_validate(schema) for schema in schemas]
         tools = [_anthropic_to_prompt_tool(anthropic_tool) for anthropic_tool in anthropic_tools]
     else:
         raise ValueError(f"Unsupported model provider: {model_provider}")
     ans = PromptTools(type="tools", tools=tools)
+
     if tool_choice is not None:
-        if model_provider is ModelProvider.OPENAI or model_provider is ModelProvider.AZURE_OPENAI:
+        if (
+            model_provider is ModelProvider.OPENAI
+            or model_provider is ModelProvider.AZURE_OPENAI
+            or model_provider is ModelProvider.DEEPSEEK
+            or model_provider is ModelProvider.XAI
+            or model_provider is ModelProvider.OLLAMA
+        ):
             ans.tool_choice = OpenAIToolChoiceConversion.from_openai(tool_choice)  # type: ignore[arg-type]
+        elif model_provider is ModelProvider.AWS:
+            ans.tool_choice = AwsToolChoiceConversion.from_aws(tool_choice)  # type: ignore[arg-type]
         elif model_provider is ModelProvider.ANTHROPIC:
             choice, disable_parallel_tool_calls = AnthropicToolChoiceConversion.from_anthropic(
                 tool_choice  # type: ignore[arg-type]
@@ -524,12 +592,22 @@ def denormalize_tools(
     tools: PromptTools, model_provider: ModelProvider
 ) -> tuple[list[dict[str, Any]], Optional[Any]]:
     assert tools.type == "tools"
-    denormalized_tools: list[PromptModel]
+    denormalized_tools: list[DBBaseModel]
     tool_choice: Optional[Any] = None
-    if model_provider is ModelProvider.OPENAI or model_provider is ModelProvider.AZURE_OPENAI:
+    if (
+        model_provider is ModelProvider.OPENAI
+        or model_provider is ModelProvider.AZURE_OPENAI
+        or model_provider is ModelProvider.DEEPSEEK
+        or model_provider is ModelProvider.XAI
+        or model_provider is ModelProvider.OLLAMA
+    ):
         denormalized_tools = [_prompt_to_openai_tool(tool) for tool in tools.tools]
         if tools.tool_choice:
             tool_choice = OpenAIToolChoiceConversion.to_openai(tools.tool_choice)
+    elif model_provider is ModelProvider.AWS:
+        denormalized_tools = [_prompt_to_bedrock_tool(tool) for tool in tools.tools]
+        if tools.tool_choice:
+            tool_choice = OpenAIToolChoiceConversion.to_openai(tools.tool_choice)
     elif model_provider is ModelProvider.ANTHROPIC:
         denormalized_tools = [_prompt_to_anthropic_tool(tool) for tool in tools.tools]
         if tools.tool_choice and tools.tool_choice.type != "none":
@@ -573,6 +651,19 @@ def _prompt_to_openai_tool(
     )
 
 
+def _bedrock_to_prompt_tool(
+    tool: BedrockToolDefinition,
+) -> PromptToolFunction:
+    return PromptToolFunction(
+        type="function",
+        function=PromptToolFunctionDefinition(
+            name=tool.toolSpec["name"],
+            description=tool.toolSpec["description"],
+            parameters=tool.toolSpec["inputSchema"]["json"],
+        ),
+    )
+
+
 def _anthropic_to_prompt_tool(
     tool: AnthropicToolDefinition,
 ) -> PromptToolFunction:
@@ -595,3 +686,18 @@ def _prompt_to_anthropic_tool(
         name=function.name,
         description=function.description,
     )
+
+
+def _prompt_to_bedrock_tool(
+    tool: PromptToolFunction,
+) -> BedrockToolDefinition:
+    function = tool.function
+    return BedrockToolDefinition(
+        toolSpec={
+            "name": function.name,
+            "description": function.description,
+            "inputSchema": {
+                "json": function.parameters,
+            },
+        }
+    )
