@@ -1,6 +1,8 @@
 from enum import Enum
+from typing import Optional
 
 import strawberry
+from strawberry import UNSET
 
 
 @strawberry.enum
@@ -10,5 +12,6 @@ class DatasetFilterColumn(Enum):
 
 @strawberry.input(description="A filter for datasets")
 class DatasetFilter:
-    col: DatasetFilterColumn
-    value: str
+    col: Optional[DatasetFilterColumn] = None
+    value: Optional[str] = None
+    filter_labels: Optional[list[str]] = UNSET
