@@ -1,6 +1,6 @@
 from collections.abc import AsyncIterable
 from datetime import datetime
-from typing import ClassVar, Optional, cast
+from typing import Optional, cast
 
 import strawberry
 from sqlalchemy import Text, and_, func, or_, select
@@ -18,8 +18,8 @@ from phoenix.server.api.types.DatasetExample import DatasetExample
 from phoenix.server.api.types.DatasetExperimentAnnotationSummary import (
     DatasetExperimentAnnotationSummary,
 )
-from phoenix.server.api.types.DatasetLabel import DatasetLabel, to_gql_dataset_label
-from phoenix.server.api.types.DatasetSplit import DatasetSplit, to_gql_dataset_split
+from phoenix.server.api.types.DatasetLabel import DatasetLabel
+from phoenix.server.api.types.DatasetSplit import DatasetSplit
 from phoenix.server.api.types.DatasetVersion import DatasetVersion
 from phoenix.server.api.types.Experiment import Experiment, to_gql_experiment
 from phoenix.server.api.types.node import from_global_id_with_expected_type
@@ -33,13 +33,77 @@ from phoenix.server.api.types.SortDir import SortDir
 
 @strawberry.type
 class Dataset(Node):
-    _table: ClassVar[type[models.Base]] = models.Experiment
-    id_attr: NodeID[int]
-    name: str
-    description: Optional[str]
-    metadata: JSON
-    created_at: datetime
-    updated_at: datetime
+    id: NodeID[int]
+    db_record: strawberry.Private[Optional[models.Dataset]] = None
+
+    def __post_init__(self) -> None:
+        if self.db_record and self.id != self.db_record.id:
+            raise ValueError("Dataset ID mismatch")
+
+    @strawberry.field
+    async def name(
+        self,
+        info: Info[Context, None],
+    ) -> str:
+        if self.db_record:
+            val = self.db_record.name
+        else:
+            val = await info.context.data_loaders.dataset_fields.load(
+                (self.id, models.Dataset.name),
+            )
+        return val
+
+    @strawberry.field
+    async def description(
+        self,
+        info: Info[Context, None],
+    ) -> Optional[str]:
+        if self.db_record:
+            val = self.db_record.description
+        else:
+            val = await info.context.data_loaders.dataset_fields.load(
+                (self.id, models.Dataset.description),
+            )
+        return val
+
+    @strawberry.field
+    async def metadata(
+        self,
+        info: Info[Context, None],
+    ) -> JSON:
+        if self.db_record:
+            val = self.db_record.metadata_
+        else:
+            val = await info.context.data_loaders.dataset_fields.load(
+                (self.id, models.Dataset.metadata_),
+            )
+        return val
+
+    @strawberry.field
+    async def created_at(
+        self,
+        info: Info[Context, None],
+    ) -> datetime:
+        if self.db_record:
+            val = self.db_record.created_at
+        else:
+            val = await info.context.data_loaders.dataset_fields.load(
+                (self.id, models.Dataset.created_at),
+            )
+        return val
+
+    @strawberry.field
+    async def updated_at(
+        self,
+        info: Info[Context, None],
+    ) -> datetime:
+        if self.db_record:
+            val = self.db_record.updated_at
+        else:
+            val = await info.context.data_loaders.dataset_fields.load(
+                (self.id, models.Dataset.updated_at),
+            )
+        return val
 
     @strawberry.field
     async def versions(
@@ -58,7 +122,7 @@ class Dataset(Node):
             before=before if isinstance(before, CursorString) else None,
         )
         async with info.context.db() as session:
-            stmt = select(models.DatasetVersion).filter_by(dataset_id=self.id_attr)
+            stmt = select(models.DatasetVersion).filter_by(dataset_id=self.id)
             if sort:
                 # For now assume the the column names match 1:1 with the enum values
                 sort_col = getattr(models.DatasetVersion, sort.col.value)
@@ -69,15 +133,7 @@ class Dataset(Node):
             else:
                 stmt = stmt.order_by(models.DatasetVersion.created_at.desc())
             versions = await session.scalars(stmt)
-        data = [
-            DatasetVersion(
-                id_attr=version.id,
-                description=version.description,
-                metadata=version.metadata_,
-                created_at=version.created_at,
-            )
-            for version in versions
-        ]
+        data = [DatasetVersion(id=version.id, db_record=version) for version in versions]
         return connection_from_list(data=data, args=args)
 
     @strawberry.field(
@@ -90,7 +146,7 @@ class Dataset(Node):
         dataset_version_id: Optional[GlobalID] = UNSET,
         split_ids: Optional[list[GlobalID]] = UNSET,
     ) -> int:
-        dataset_id = self.id_attr
+        dataset_id = self.id
         version_id = (
             from_global_id_with_expected_type(
                 global_id=dataset_version_id,
@@ -180,7 +236,7 @@ class Dataset(Node):
             last=last,
             before=before if isinstance(before, CursorString) else None,
         )
-        dataset_id = self.id_attr
+        dataset_id = self.id
         version_id = (
             from_global_id_with_expected_type(
                 global_id=dataset_version_id, expected_type_name=DatasetVersion.__name__
@@ -231,7 +287,7 @@ class Dataset(Node):
                     models.DatasetExampleRevision.revision_kind != "DELETE",
                 )
             )
-            .order_by(models.DatasetExampleRevision.dataset_example_id.desc())
+            .order_by(models.DatasetExample.id.desc())
         )
 
         # Filter by split IDs if provided
@@ -261,9 +317,9 @@ class Dataset(Node):
         async with info.context.db() as session:
             dataset_examples = [
                 DatasetExample(
-                    id_attr=example.id,
+                    id=example.id,
+                    db_record=example,
                     version_id=version_id,
-                    created_at=example.created_at,
                 )
                 async for example in await session.stream_scalars(query)
             ]
@@ -272,8 +328,8 @@ class Dataset(Node):
     @strawberry.field
     async def splits(self, info: Info[Context, None]) -> list[DatasetSplit]:
         return [
-            to_gql_dataset_split(split)
-            for split in await info.context.data_loaders.dataset_dataset_splits.load(self.id_attr)
+            DatasetSplit(id=split.id, db_record=split)
+            for split in await info.context.data_loaders.dataset_dataset_splits.load(self.id)
         ]
 
     @strawberry.field(
@@ -285,9 +341,7 @@ class Dataset(Node):
         info: Info[Context, None],
         dataset_version_id: Optional[GlobalID] = UNSET,
     ) -> int:
-        stmt = select(count(models.Experiment.id)).where(
-            models.Experiment.dataset_id == self.id_attr
-        )
+        stmt = select(count(models.Experiment.id)).where(models.Experiment.dataset_id == self.id)
         version_id = (
             from_global_id_with_expected_type(
                 global_id=dataset_version_id,
@@ -320,7 +374,7 @@ class Dataset(Node):
             last=last,
             before=before if isinstance(before, CursorString) else None,
         )
-        dataset_id = self.id_attr
+        dataset_id = self.id
         row_number = func.row_number().over(order_by=models.Experiment.id).label("row_number")
         query = (
             select(models.Experiment, row_number)
@@ -363,7 +417,7 @@ class Dataset(Node):
     async def experiment_annotation_summaries(
         self, info: Info[Context, None]
     ) -> list[DatasetExperimentAnnotationSummary]:
-        dataset_id = self.id_attr
+        dataset_id = self.id
         query = (
             select(
                 models.ExperimentRunAnnotation.name.label("annotation_name"),
@@ -396,24 +450,10 @@ class Dataset(Node):
     @strawberry.field
     async def labels(self, info: Info[Context, None]) -> list[DatasetLabel]:
         return [
-            to_gql_dataset_label(label)
-            for label in await info.context.data_loaders.dataset_labels.load(self.id_attr)
+            DatasetLabel(id=label.id, db_record=label)
+            for label in await info.context.data_loaders.dataset_labels.load(self.id)
         ]
 
     @strawberry.field
     def last_updated_at(self, info: Info[Context, None]) -> Optional[datetime]:
-        return info.context.last_updated_at.get(self._table, self.id_attr)
-
-
-def to_gql_dataset(dataset: models.Dataset) -> Dataset:
-    """
-    Converts an ORM dataset to a GraphQL dataset.
-    """
-    return Dataset(
-        id_attr=dataset.id,
-        name=dataset.name,
-        description=dataset.description,
-        metadata=dataset.metadata_,
-        created_at=dataset.created_at,
-        updated_at=dataset.updated_at,
-    )
+        return info.context.last_updated_at.get(models.Dataset, self.id)
