@@ -1,9 +1,8 @@
 from datetime import datetime
-from typing import Optional
+from typing import TYPE_CHECKING, Annotated, Optional
 
 import strawberry
 from sqlalchemy import select
-from sqlalchemy.orm import joinedload
 from strawberry import UNSET
 from strawberry.relay.types import Connection, GlobalID, Node, NodeID
 from strawberry.types import Info
@@ -12,34 +11,49 @@ from phoenix.db import models
 from phoenix.server.api.context import Context
 from phoenix.server.api.exceptions import BadRequest
 from phoenix.server.api.types.DatasetExampleRevision import DatasetExampleRevision
-from phoenix.server.api.types.DatasetSplit import DatasetSplit, to_gql_dataset_split
+from phoenix.server.api.types.DatasetSplit import DatasetSplit
 from phoenix.server.api.types.DatasetVersion import DatasetVersion
 from phoenix.server.api.types.ExperimentRepeatedRunGroup import (
     ExperimentRepeatedRunGroup,
 )
-from phoenix.server.api.types.ExperimentRun import ExperimentRun, to_gql_experiment_run
+from phoenix.server.api.types.ExperimentRun import ExperimentRun
 from phoenix.server.api.types.node import from_global_id_with_expected_type
 from phoenix.server.api.types.pagination import (
     ConnectionArgs,
     CursorString,
     connection_from_list,
 )
-from phoenix.server.api.types.Span import Span
+
+if TYPE_CHECKING:
+    from .Span import Span
 
 
 @strawberry.type
 class DatasetExample(Node):
-    id_attr: NodeID[int]
-    created_at: datetime
+    id: NodeID[int]
+    db_record: strawberry.Private[Optional[models.DatasetExample]] = None
     version_id: strawberry.Private[Optional[int]] = None
 
+    def __post_init__(self) -> None:
+        if self.db_record and self.id != self.db_record.id:
+            raise ValueError("DatasetExample ID mismatch")
+
+    @strawberry.field
+    async def created_at(self, info: Info[Context, None]) -> datetime:
+        if self.db_record:
+            val = self.db_record.created_at
+        else:
+            val = await info.context.data_loaders.dataset_example_fields.load(
+                (self.id, models.DatasetExample.created_at),
+            )
+        return val
+
     @strawberry.field
     async def revision(
         self,
         info: Info[Context, None],
         dataset_version_id: Optional[GlobalID] = UNSET,
     ) -> DatasetExampleRevision:
-        example_id = self.id_attr
         version_id: Optional[int] = None
         if dataset_version_id:
             version_id = from_global_id_with_expected_type(
@@ -47,18 +61,18 @@ class DatasetExample(Node):
             )
         elif self.version_id is not None:
             version_id = self.version_id
-        return await info.context.data_loaders.dataset_example_revisions.load(
-            (example_id, version_id)
-        )
+        return await info.context.data_loaders.dataset_example_revisions.load((self.id, version_id))
 
     @strawberry.field
     async def span(
         self,
         info: Info[Context, None],
-    ) -> Optional[Span]:
+    ) -> Optional[Annotated["Span", strawberry.lazy(".Span")]]:
+        from .Span import Span
+
         return (
-            Span(span_rowid=span.id, db_span=span)
-            if (span := await info.context.data_loaders.dataset_example_spans.load(self.id_attr))
+            Span(id=span.id, db_record=span)
+            if (span := await info.context.data_loaders.dataset_example_spans.load(self.id))
             else None
         )
 
@@ -78,12 +92,10 @@ class DatasetExample(Node):
             last=last,
             before=before if isinstance(before, CursorString) else None,
         )
-        example_id = self.id_attr
         query = (
             select(models.ExperimentRun)
-            .options(joinedload(models.ExperimentRun.trace).load_only(models.Trace.trace_id))
             .join(models.Experiment, models.Experiment.id == models.ExperimentRun.experiment_id)
-            .where(models.ExperimentRun.dataset_example_id == example_id)
+            .where(models.ExperimentRun.dataset_example_id == self.id)
             .order_by(
                 models.ExperimentRun.experiment_id.asc(),
                 models.ExperimentRun.repetition_number.asc(),
@@ -100,7 +112,7 @@ class DatasetExample(Node):
             query = query.where(models.ExperimentRun.experiment_id.in_(experiment_db_ids))
         async with info.context.db() as session:
             runs = (await session.scalars(query)).all()
-        return connection_from_list([to_gql_experiment_run(run) for run in runs], args)
+        return connection_from_list([ExperimentRun(id=run.id, db_record=run) for run in runs], args)
 
     @strawberry.field
     async def experiment_repeated_run_groups(
@@ -108,7 +120,6 @@ class DatasetExample(Node):
         info: Info[Context, None],
         experiment_ids: list[GlobalID],
     ) -> list[ExperimentRepeatedRunGroup]:
-        example_rowid = self.id_attr
         experiment_rowids = []
         for experiment_id in experiment_ids:
             try:
@@ -121,14 +132,14 @@ class DatasetExample(Node):
             experiment_rowids.append(experiment_rowid)
         repeated_run_groups = (
             await info.context.data_loaders.experiment_repeated_run_groups.load_many(
-                [(experiment_rowid, example_rowid) for experiment_rowid in experiment_rowids]
+                [(experiment_rowid, self.id) for experiment_rowid in experiment_rowids]
             )
         )
         return [
             ExperimentRepeatedRunGroup(
                 experiment_rowid=group.experiment_rowid,
                 dataset_example_rowid=group.dataset_example_rowid,
-                runs=[to_gql_experiment_run(run) for run in group.runs],
+                cached_runs=[ExperimentRun(id=run.id, db_record=run) for run in group.runs],
             )
             for group in repeated_run_groups
         ]
@@ -139,13 +150,6 @@ class DatasetExample(Node):
         info: Info[Context, None],
     ) -> list[DatasetSplit]:
         return [
-            to_gql_dataset_split(split)
-            for split in await info.context.data_loaders.dataset_example_splits.load(self.id_attr)
+            DatasetSplit(id=split.id, db_record=split)
+            for split in await info.context.data_loaders.dataset_example_splits.load(self.id)
         ]
-
-
-def to_gql_dataset_example(example: models.DatasetExample) -> DatasetExample:
-    return DatasetExample(
-        id_attr=example.id,
-        created_at=example.created_at,
-    )
