@@ -6,6 +6,7 @@ import strawberry
 from sqlalchemy import func, select
 from strawberry import UNSET
 from strawberry.relay import Connection, GlobalID, Node, NodeID
+from strawberry.scalars import JSON
 from strawberry.types import Info
 
 from phoenix.db import models
@@ -20,21 +21,89 @@ from phoenix.server.api.types.pagination import (
     connection_from_list,
 )
 
-from .PromptLabel import PromptLabel, to_gql_prompt_label
+from .PromptLabel import PromptLabel
 from .PromptVersion import (
     PromptVersion,
     to_gql_prompt_version,
 )
-from .PromptVersionTag import PromptVersionTag, to_gql_prompt_version_tag
+from .PromptVersionTag import PromptVersionTag
 
 
 @strawberry.type
 class Prompt(Node):
-    id_attr: NodeID[int]
-    source_prompt_id: Optional[GlobalID]
-    name: Identifier
-    description: Optional[str]
-    created_at: datetime
+    id: NodeID[int]
+    db_record: strawberry.Private[Optional[models.Prompt]] = None
+
+    def __post_init__(self) -> None:
+        if self.db_record and self.id != self.db_record.id:
+            raise ValueError("Prompt ID mismatch")
+
+    @strawberry.field
+    async def source_prompt_id(
+        self,
+        info: Info[Context, None],
+    ) -> Optional[GlobalID]:
+        if self.db_record:
+            source_id = self.db_record.source_prompt_id
+        else:
+            source_id = await info.context.data_loaders.prompt_fields.load(
+                (self.id, models.Prompt.source_prompt_id),
+            )
+        if not source_id:
+            return None
+        return GlobalID(Prompt.__name__, str(source_id))
+
+    @strawberry.field
+    async def name(
+        self,
+        info: Info[Context, None],
+    ) -> Identifier:
+        if self.db_record:
+            val = self.db_record.name
+        else:
+            val = await info.context.data_loaders.prompt_fields.load(
+                (self.id, models.Prompt.name),
+            )
+        return Identifier(val.root)
+
+    @strawberry.field
+    async def description(
+        self,
+        info: Info[Context, None],
+    ) -> Optional[str]:
+        if self.db_record:
+            val = self.db_record.description
+        else:
+            val = await info.context.data_loaders.prompt_fields.load(
+                (self.id, models.Prompt.description),
+            )
+        return val
+
+    @strawberry.field
+    async def metadata(
+        self,
+        info: Info[Context, None],
+    ) -> JSON:
+        if self.db_record:
+            val = self.db_record.metadata_
+        else:
+            val = await info.context.data_loaders.prompt_fields.load(
+                (self.id, models.Prompt.metadata_),
+            )
+        return val
+
+    @strawberry.field
+    async def created_at(
+        self,
+        info: Info[Context, None],
+    ) -> datetime:
+        if self.db_record:
+            val = self.db_record.created_at
+        else:
+            val = await info.context.data_loaders.prompt_fields.load(
+                (self.id, models.Prompt.created_at),
+            )
+        return val
 
     @strawberry.field
     async def version(
@@ -49,7 +118,7 @@ class Prompt(Node):
                 version = await session.scalar(
                     select(models.PromptVersion).where(
                         models.PromptVersion.id == v_id,
-                        models.PromptVersion.prompt_id == self.id_attr,
+                        models.PromptVersion.prompt_id == self.id,
                     )
                 )
                 if not version:
@@ -61,7 +130,7 @@ class Prompt(Node):
                     raise NotFound(f"Prompt version tag not found: {tag_name}")
                 version = await session.scalar(
                     select(models.PromptVersion)
-                    .where(models.PromptVersion.prompt_id == self.id_attr)
+                    .where(models.PromptVersion.prompt_id == self.id)
                     .join_from(models.PromptVersion, models.PromptVersionTag)
                     .where(models.PromptVersionTag.name == name)
                 )
@@ -70,7 +139,7 @@ class Prompt(Node):
             else:
                 stmt = (
                     select(models.PromptVersion)
-                    .where(models.PromptVersion.prompt_id == self.id_attr)
+                    .where(models.PromptVersion.prompt_id == self.id)
                     .order_by(models.PromptVersion.id.desc())
                     .limit(1)
                 )
@@ -83,10 +152,11 @@ class Prompt(Node):
     async def version_tags(self, info: Info[Context, None]) -> list[PromptVersionTag]:
         async with info.context.db() as session:
             stmt = select(models.PromptVersionTag).where(
-                models.PromptVersionTag.prompt_id == self.id_attr
+                models.PromptVersionTag.prompt_id == self.id
             )
             return [
-                to_gql_prompt_version_tag(tag) async for tag in await session.stream_scalars(stmt)
+                PromptVersionTag(id=tag.id, db_record=tag)
+                async for tag in await session.stream_scalars(stmt)
             ]
 
     @strawberry.field
@@ -107,7 +177,7 @@ class Prompt(Node):
         row_number = func.row_number().over(order_by=models.PromptVersion.id).label("row_number")
         stmt = (
             select(models.PromptVersion, row_number)
-            .where(models.PromptVersion.prompt_id == self.id_attr)
+            .where(models.PromptVersion.prompt_id == self.id)
             .order_by(models.PromptVersion.id.desc())
         )
         async with info.context.db() as session:
@@ -119,20 +189,19 @@ class Prompt(Node):
 
     @strawberry.field
     async def source_prompt(self, info: Info[Context, None]) -> Optional["Prompt"]:
-        if not self.source_prompt_id:
-            return None
-
-        source_prompt_id = from_global_id_with_expected_type(
-            global_id=self.source_prompt_id, expected_type_name=Prompt.__name__
-        )
-
-        async with info.context.db() as session:
-            source_prompt = await session.scalar(
-                select(models.Prompt).where(models.Prompt.id == source_prompt_id)
+        if self.db_record:
+            id_ = self.db_record.source_prompt_id
+        else:
+            id_ = await info.context.data_loaders.prompt_fields.load(
+                (self.id, models.Prompt.source_prompt_id),
             )
-            if not source_prompt:
-                raise NotFound(f"Source prompt not found: {self.source_prompt_id}")
-            return to_gql_prompt_from_orm(source_prompt)
+        if not id_:
+            return None
+        async with info.context.db() as session:
+            source_prompt = await session.get(models.Prompt, id_)
+        if not source_prompt:
+            raise NotFound(f"Source prompt not found: {id_}")
+        return Prompt(id=source_prompt.id, db_record=source_prompt)
 
     @strawberry.field
     async def labels(self, info: Info[Context, None]) -> list["PromptLabel"]:
@@ -140,23 +209,6 @@ class Prompt(Node):
             labels = await session.scalars(
                 select(models.PromptLabel)
                 .join(models.PromptPromptLabel)
-                .where(models.PromptPromptLabel.prompt_id == self.id_attr)
+                .where(models.PromptPromptLabel.prompt_id == self.id)
             )
-            return [to_gql_prompt_label(label) for label in labels]
-
-
-def to_gql_prompt_from_orm(orm_model: "models.Prompt") -> Prompt:
-    if not orm_model.source_prompt_id:
-        source_prompt_gid = None
-    else:
-        source_prompt_gid = GlobalID(
-            Prompt.__name__,
-            str(orm_model.source_prompt_id),
-        )
-    return Prompt(
-        id_attr=orm_model.id,
-        source_prompt_id=source_prompt_gid,
-        name=Identifier(orm_model.name.root),
-        description=orm_model.description,
-        created_at=orm_model.created_at,
-    )
+            return [PromptLabel(id=label.id, db_record=label) for label in labels]
